#############
API Reference
#############


.. currentmodule:: jax_verify

Verification methods
====================

.. autofunction:: crown_bound_propagation

.. autofunction:: crownibp_bound_propagation

.. autofunction:: fastlin_bound_propagation

.. autofunction:: ibpfastlin_bound_propagation

.. autofunction:: interval_bound_propagation

.. autofunction:: solve_planet_relaxation

Bound objects
=============

.. autoclass:: LinearBound

.. autoclass:: IntervalBound


Utility methods
===============

.. autofunction:: open_file
